.. currentmodule:: pyhomogenize

Basic functions for controlling netCDF CF standard time axis
------------------------------------------------------------

.. autoclass:: basics

   .. automethod:: __init__

   .. rubric:: Methods

   .. autosummary::

      basics.str_to_date

      basics.date_to_str

      basics.is_month_start

      basics.is_month_end

      basics.date_range

      basics.date_range_to_frequency_limits

   .. rubric:: Attributes

   .. autosummary::

      basics.fmt

      basics.calendar

      basics.frequency
